@@ -1,5 +1,3 @@
-/* $Id: procopenfiles.h,v 1.3 2005/01/24 14:27:18 bdejean Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    Copyright (C) 2004 Nicolás Lichtmaier
    This file is part of LibGTop 1.0.
@@ -88,13 +86,14 @@ struct _glibtop_open_files_entry
 
 struct _glibtop_proc_open_files
 {
-	guint64	flags,
-		number,			/* GLIBTOP_PROC_OPEN_FILES_NUMBER */
-		total,			/* GLIBTOP_PROC_OPEN_FILES_TOTAL  */
-		size;			/* GLIBTOP_PROC_OPEN_FILES_SIZE   */
+	guint64	flags;
+	guint64 number;			/* GLIBTOP_PROC_OPEN_FILES_NUMBER */
+	guint64 total;			/* GLIBTOP_PROC_OPEN_FILES_TOTAL  */
+	guint64 size;			/* GLIBTOP_PROC_OPEN_FILES_SIZE   */
 };
 
-#define glibtop_get_proc_open_files(proc_open_files,pid) glibtop_get_proc_open_files_l(glibtop_global_server, proc_open_files, pid)
+glibtop_open_files_entry *
+glibtop_get_proc_open_files(glibtop_proc_open_files *buf, pid_t pid);
 
 #if GLIBTOP_SUID_PROC_FILE
 #define glibtop_get_proc_open_files_r		glibtop_get_proc_open_files_p
