@@ -1,5 +1,3 @@
-/* $Id: uptime.h,v 1.26 2005/06/07 09:54:43 bdejean Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -40,8 +38,8 @@ typedef struct _glibtop_uptime	glibtop_uptime;
 struct _glibtop_uptime
 {
 	guint64 flags;
-	double uptime,		/* GLIBTOP_UPTIME_UPTIME	*/
-		idletime;	/* GLIBTOP_UPTIME_IDLETIME	*/
+	double uptime;		/* GLIBTOP_UPTIME_UPTIME	*/
+	double idletime;	/* GLIBTOP_UPTIME_IDLETIME	*/
 	guint64 boot_time;
 };
 
