@@ -1,5 +1,3 @@
-/* $Id: procmap.c,v 1.4 2004/06/09 18:52:21 bdejean Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -22,6 +20,7 @@
 */
 
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/procmap.h>
@@ -41,7 +40,7 @@ glibtop_init_proc_map_s (glibtop *server)
 glibtop_map_entry *
 glibtop_get_proc_map_s (glibtop *server, glibtop_proc_map *buf,	pid_t pid)
 {
-	glibtop_init_p (&server, GLIBTOP_SYSDEPS_PROC_MAP, 0);
+	glibtop_init_p (&server, (1L << GLIBTOP_SYSDEPS_PROC_MAP), 0);
 
 	memset (buf, 0, sizeof (glibtop_proc_map));
 
