@@ -540,6 +540,7 @@ static gboolean ignore_mount_entry(const struct mount_entry *me)
 	static const char ignored[][12] = {
 		"autofs",
 		"binfmt_misc",
+		"ctfs",
 		"devfs",
 		"devpts",
 		"linprocfs",
@@ -547,6 +548,8 @@ static gboolean ignore_mount_entry(const struct mount_entry *me)
 		"mntfs",
 		"mqueue",
 		"none",
+		"nsfd",
+		"objfs",
 		"openpromfs",
 		"proc",
 		"procfs",
