@@ -1,5 +1,3 @@
-/* $Id: glibtop_server.h,v 1.31 2004/11/28 01:32:55 bdejean Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -43,6 +41,8 @@
 #define GLIBTOP_SUID_PROC_ARGS		0
 #define GLIBTOP_SUID_PROC_MAP		0
 #define GLIBTOP_SUID_NETLOAD		0
+#define GLIBTOP_SUID_NETLIST		0
 #define GLIBTOP_SUID_PPP		0
+#define GLIBTOP_SUID_PROC_FILE		0
 
 #endif /* __LINUX__GLIBTOP_SERVER_H__ */
