@@ -1,5 +1,3 @@
-/* $Id: proclist.c,v 1.27 2005/12/12 13:32:06 bdejean Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -98,8 +96,18 @@ glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
 				continue;
 			break;
 		case GLIBTOP_KERN_PROC_UID:
-			if ((uid_t) arg != statb.st_uid)
+		{
+			char path[32];
+			struct stat path_stat;
+
+			snprintf(path, sizeof path, "/proc/%u", pid);
+
+			if (stat(path, &path_stat))
 				continue;
+
+			if ((uid_t) arg != path_stat.st_uid)
+				continue;
+		}
 			break;
 		case GLIBTOP_KERN_PROC_PGRP:
 			/* Do you really, really need this ? */
