@@ -1,5 +1,3 @@
-/* $Id: proclist.c,v 1.9 2003/10/19 16:55:51 carlos Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -21,6 +19,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/proclist.h>
@@ -39,10 +38,10 @@ glibtop_init_proclist_p (glibtop *server)
 
 unsigned *
 glibtop_get_proclist_p (glibtop *server, glibtop_proclist *buf,
-			int64_t which, int64_t arg)
+			gint64 which, gint64 arg)
 {
 	glibtop_init_p (server, GLIBTOP_SYSDEPS_PROCLIST, 0);
-	
+
 	memset (buf, 0, sizeof (glibtop_proclist));
 
 	return NULL;
